@@ -2,6 +2,8 @@ from decimal import Decimal, DecimalException
 from urllib.parse import urlencode
 
 from django.conf import settings as django_settings
+from django.core.exceptions import ObjectDoesNotExist, ValidationError
+from django.core.validators import URLValidator
 from django.urls import reverse
 from django.views.decorators.clickjacking import xframe_options_exempt
 from django.shortcuts import redirect
@@ -105,21 +107,19 @@ def post_interactive_withdraw(request: Request) -> Response:
                     "The anchor did not provide content, is the interactive flow already complete?"
                 ),
                 status_code=422,
-                content_type="text/html",
+                as_html=True,
             )
         return render_error_response(
             _("The anchor did not provide content, unable to serve page."),
             status_code=500,
-            content_type="text/html",
+            as_html=True,
         )
 
     if not form.is_bound:
         # The anchor must initialize the form with request.data
         logger.error("form returned was not initialized with POST data, returning 500")
         return render_error_response(
-            _("Unable to validate form submission."),
-            status_code=500,
-            content_type="text/html",
+            _("Unable to validate form submission."), status_code=500, as_html=True
         )
 
     elif form.is_valid():
@@ -266,16 +266,42 @@ def complete_interactive_withdraw(request: Request) -> Response:
     """
     GET /transactions/withdraw/interactive/complete
 
-    Updates the transaction status to pending_user_transfer_start and
-    redirects to GET /more_info. A `callback` can be passed in the URL
-    to be used by the more_info template javascript.
+    This endpoint serves as a proxy to the
+    ``WithdrawalIntegration.after_interactive_flow()`` function, which should be
+    implemented if ``WithdrawalIntegration.interactive_url()`` is also implemented.
+
+    Anchors using external interactive flows should redirect to this endpoint
+    from the external application once complete so that the Polaris `Transaction`
+    record can be updated with the appropriate information collected within the
+    interactive flow.
+
+    After allowing the anchor to process the information sent, this endpoint will
+    redirect to the transaction's more info page, which will make the SEP-24
+    callback request if requested by the client.
+
+    Note that the more info page's template and related CSS should be updated
+    if the anchor wants to keep the brand experience consistent with the external
+    application seen by the user immediately prior.
     """
-    transaction_id = request.GET.get("transaction_id")
-    callback = request.GET.get("callback")
-    Transaction.objects.filter(id=transaction_id).update(
-        status=Transaction.STATUS.pending_user_transfer_start
-    )
-    logger.info(f"Hands-off interactive flow complete for transaction {transaction_id}")
+    transaction_id = request.query_params.get("transaction_id")
+    callback = request.query_params.get("callback")
+    try:
+        transaction = Transaction.objects.get(id=transaction_id)
+    except ObjectDoesNotExist:
+        return render_error_response(
+            _("transaction not found"), status_code=404, as_html=True
+        )
+    if callback and callback.lower() != "postmessage":
+        try:
+            URLValidator(schemes=["https", "http"])(callback)
+        except ValidationError:
+            return render_error_response(
+                _("invalid 'callback' URL"), status_code=400, as_html=True
+            )
+    try:
+        rwi.after_interactive_flow(request=request, transaction=transaction)
+    except NotImplementedError:
+        return render_error_response(_("internal error"), status_code=500, as_html=True)
     args = {"id": transaction_id, "initialLoad": "true"}
     if callback:
         args["callback"] = callback
@@ -354,12 +380,12 @@ def get_interactive_withdraw(request: Request) -> Response:
                     "The anchor did not provide content, is the interactive flow already complete?"
                 ),
                 status_code=422,
-                content_type="text/html",
+                as_html=True,
             )
         return render_error_response(
             _("The anchor did not provide content, unable to serve page."),
             status_code=500,
-            content_type="text/html",
+            as_html=True,
         )
 
     url_args = {"transaction_id": transaction.id, "asset_code": asset.code}
